@@ -1,11 +1,13 @@
 baremodule UnsafeAtomics
 
 abstract type Ordering end
+abstract type SyncScope end
 
 function load end
 function store! end
 function cas! end
 function modify! end
+function fence end
 
 function add! end
 function sub! end
@@ -17,6 +19,7 @@ function xor! end
 function max! end
 function min! end
 
+# =>
 right(_, x) = x
 
 module Internal
@@ -24,10 +27,11 @@ module Internal
 using Base.Sys: WORD_SIZE
 using Base: bitcast, llvmcall
 
-using ..UnsafeAtomics: UnsafeAtomics, Ordering, right
+using ..UnsafeAtomics: UnsafeAtomics, Ordering, SyncScope, right
 
 include("utils.jl")
 include("orderings.jl")
+include("syncscopes.jl")
 include("core.jl")
 
 end  # module Internal
@@ -43,4 +47,8 @@ const seq_cst = Internal.seq_cst
 const acquire_release = acq_rel
 const sequentially_consistent = seq_cst
 
+# SyncScope
+const none = Internal.none
+const singlethread = Internal.singlethread
+
 end  # baremodule UnsafeAtomics
